# Miyaji Lab Collections
A collection of utilities used by Miyaji Lab for researches, lectures, etc.

## Example Usage
```python
from myjlab.pbl.utils import str_to_int, int_to_str

str_to_int('こんにちは')    # 1181279534677122504641669074077843887
int_to_str(1181279534677122504641669074077843887)    # こんにちは
```
